@@ -3,6 +3,9 @@
 # /usr/local/sbin/start-linpac.sh
 # dranch@arrl.net
 
+# 01/13/21 - add checks for the presence of screen
+#          - removed the use of sudo to better support running as non-root
+#          - Use a variable for log destination and append to the existing log
 # 09/02/17 - Added a check for stale lock files
 # 11/29/15 - Removed screen logging as it doesn't work well for Ncurses UIs
 #          - Start linpac and then attach to it if possible
@@ -19,6 +22,16 @@
 #
 #   Don't enable screen logging (-L) as it just creates ANSI trash in the logs
 
+# Variables
+#-----------
+LINPACLOG="/var/log/linpac.log"
+
+which screen > /dev/null
+if [ $? -ne 0 ]; then
+   echo -e "screen is not installed but is required.  Aborting."
+   exit 1
+fi
+
 if [ -n "`ps aux | grep -v grep | grep -i screen | grep -i linpac`" ]; then
    echo -e "\nLinpac already running under Screen.  Resuming"
    screen -d -r linpac
@@ -29,8 +42,8 @@ if [ -n "`ps aux | grep -v grep | grep -i screen | grep -i linpac`" ]; then
       echo -e "Remove this lock file and try again"
       exit 1
    fi
-   date > /var/log/linpac.log
-   screen -d -m -S linpac sudo linpac
+   date >> $LINPACLOG
+   screen -d -m -S linpac linpac
    #Comment out the following line if you don't want screen to attach to the
    # started Linpac screen session right now
    screen -d -r linpac
