@@ -38,6 +38,10 @@ class TheFile : public screen_obj
     WINDOW *old_focus_window;
     screen_obj *old_focused;
 
+    void wrap_line(char* str); // fit to screen width
+    void add_attachment_placeholder(char* line, int len); // for 7plus
+    char* filename_from_footer(char* footer); // for 7plus
+
   public:
     std::vector <char *> line;
 
@@ -85,6 +89,7 @@ class Messages : public screen_obj
   
       void clear_msgs();
       void load_list(bool all);  //re-filter messages
+      void calc_scroll_pos();
   
    public:
       //NOTE: in function arguments 'index' means index of the message
